# Porter

Checks if your desired services are running or not. Default ports are used as an example here

Contributions welcome for:

- .env.example for port and message so that ports are not revealed in forks.
- Exact finding strings instead of whitespaces


